@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003 Ariya Hidayat <ariya@kde.org>
+   Copyright (C) 2003-2005 Ariya Hidayat <ariya@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,9 +27,10 @@
 #include <excelimport.h>
 #include <excelimport.moc>
 
-#include <qstring.h>
-#include <qdom.h>
 #include <qcolor.h>
+#include <qdatetime.h>
+#include <qdom.h>
+#include <qstring.h>
 
 #include <kdebug.h>
 #include <koFilterChain.h>
@@ -38,16 +39,16 @@
 #include <kgenericfactory.h>
 #include <kmessagebox.h>
 
-#include <sidewinder.h>
+#include "swinder.h"
 #include <iostream>
 
 typedef KGenericFactory<ExcelImport, KoFilter> ExcelImportFactory;
-K_EXPORT_COMPONENT_FACTORY( libexcelimport, ExcelImportFactory( "kspreadexcelfilter" ) )
+K_EXPORT_COMPONENT_FACTORY( libexcelimport, ExcelImportFactory( "kofficefilters" ) )
 
 
 // UString -> QConstString conversion. Use .string() to get the QString.
 // Always store the QConstString into a variable first, to avoid a deep copy.
-inline QConstString string( const Sidewinder::UString& str ) {
+inline QConstString string( const Swinder::UString& str ) {
    // Let's hope there's no copying of the QConstString happening...
    return QConstString( reinterpret_cast<const QChar*>( str.data() ), str.length() );
 }
@@ -58,24 +59,24 @@ ExcelImport::ExcelImport ( QObject*, const char*, const QStringList& )
 }
 
 // convert from RGB values to "#rrggbb"
-static QString convertColor( const Sidewinder::Color& color )
+static QString convertColor( const Swinder::Color& color )
 {
   return QColor( color.red, color.green, color.blue ).name();
 }
 
-static QDomElement convertPen( QDomDocument& doc, const Sidewinder::Pen& pen )
+static QDomElement convertPen( QDomDocument& doc, const Swinder::Pen& pen )
 {
   QDomElement penElement = doc.createElement( "pen" );
 
   unsigned style = 0;
   switch( pen.style )
   {
-    case Sidewinder::Pen::NoLine:         style = 0; break;
-    case Sidewinder::Pen::SolidLine:      style = 1; break;
-    case Sidewinder::Pen::DashLine:       style = 2; break;
-    case Sidewinder::Pen::DotLine:        style = 3; break;
-    case Sidewinder::Pen::DashDotLine:    style = 4; break;
-    case Sidewinder::Pen::DashDotDotLine: style = 5; break;
+    case Swinder::Pen::NoLine:         style = 0; break;
+    case Swinder::Pen::SolidLine:      style = 1; break;
+    case Swinder::Pen::DashLine:       style = 2; break;
+    case Swinder::Pen::DotLine:        style = 3; break;
+    case Swinder::Pen::DashDotLine:    style = 4; break;
+    case Swinder::Pen::DashDotDotLine: style = 5; break;
     default: style = 1; break; // fallback, solid line
   }
 
@@ -86,23 +87,285 @@ static QDomElement convertPen( QDomDocument& doc, const Sidewinder::Pen& pen )
   return penElement;
 }
 
-QDomElement convertFormat( QDomDocument& doc, const Sidewinder::Format& format )
+static QDomElement convertFormat( QDomDocument& doc, const Swinder::Format& format )
 {
   QDomElement e = doc.createElement( "format" );
+  
+  // value format
+    
+  // NOTE this is not The Right Thing, we need to parse&compile the format string
+  // this hack only works for built-in common formats, not customized ones
+  QString vf = string( format.valueFormat()).string();
+  if( vf == "General" )
+    ;
+  else if( vf == "0" )
+    e.setAttribute("precision", "0");
+  else if( vf == "0.0" )
+    e.setAttribute("precision", "1");
+  else if( vf == "0.00" )
+    e.setAttribute("precision", "2");
+  else if( vf == "0.000" )
+    e.setAttribute("precision", "3");
+  else if( vf == "0.0000" )
+    e.setAttribute("precision", "4");
+  else if( vf == "0.00000" )
+    e.setAttribute("precision", "5");
+  else if( vf == "0.000000" )
+    e.setAttribute("precision", "6");
+  else if( vf == "0.0000000" )
+    e.setAttribute("precision", "7");
+  else if( vf == "0.00000000" )
+    e.setAttribute("precision", "8");
+  else if( vf == "0.000000000" )
+    e.setAttribute("precision", "9");
+  else if( vf == "0.0000000000" )
+    e.setAttribute("precision", "10");
+  else if( vf == "0.00000000000" )
+    e.setAttribute("precision", "11");
+  else if( vf == "0.000000000000" )
+    e.setAttribute("precision", "12");
+  else if( vf == "0.0000000000000" )
+    e.setAttribute("precision", "13");
+  else if( vf == "0.00000000000000" )
+    e.setAttribute("precision", "14");
+  else if( vf == "0.000000000000000" )
+    e.setAttribute("precision", "15");
+        
+  else if( vf == "0%" )
+  {
+    e.setAttribute("precision", "0");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.0%" )
+  {
+    e.setAttribute("precision", "1");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.00%" )
+  {
+    e.setAttribute("precision", "2");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.000%" )
+  {
+    e.setAttribute("precision", "3");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.0000%" )
+  {
+    e.setAttribute("precision", "4");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.00000%" )
+  {
+    e.setAttribute("precision", "5");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.000000%" )
+  {
+    e.setAttribute("precision", "6");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.0000000%" )
+  {
+    e.setAttribute("precision", "7");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.00000000%" )
+  {
+    e.setAttribute("precision", "8");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+
+  else if( vf == "0.000000000%" )
+  {
+    e.setAttribute("precision", "9");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.0000000000%" )
+  {
+    e.setAttribute("precision", "10");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.00000000000%" )
+  {
+    e.setAttribute("precision", "11");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.000000000000%" )
+  {
+    e.setAttribute("precision", "12");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+    
+  else if( vf == "0.0000000000000%" )
+  {
+    e.setAttribute("precision", "13");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.00000000000000%" )
+  {
+    e.setAttribute("precision", "14");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  else if( vf == "0.000000000000000%" )
+  {
+    e.setAttribute("precision", "15");
+    e.setAttribute("format", "25");
+    e.setAttribute("faktor", "100");
+  }
+  
+  else if( vf == "0E+00" )
+  {
+    e.setAttribute("precision", "0");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.0E+00" )
+  {
+    e.setAttribute("precision", "1");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.00E+00" )
+  {
+    e.setAttribute("precision", "2");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.000E+00" )
+  {
+    e.setAttribute("precision", "3");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.0000E+00" )
+  {
+    e.setAttribute("precision", "4");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.00000E+00" )
+  {
+    e.setAttribute("precision", "5");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.000000E+00" )
+  {
+    e.setAttribute("precision", "6");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.0000000E+00" )
+  {
+    e.setAttribute("precision", "7");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.00000000E+00" )
+  {
+    e.setAttribute("precision", "8");
+    e.setAttribute("format", "30");
+  }  
+  else if( vf == "0.000000000E+00" )
+  {
+    e.setAttribute("precision", "9");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.0000000000E+00" )
+  {
+    e.setAttribute("precision", "10");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.00000000000E+00" )
+  {
+    e.setAttribute("precision", "11");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.000000000000E+00" )
+  {
+    e.setAttribute("precision", "12");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.0000000000000E+00" )
+  {
+    e.setAttribute("precision", "13");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.00000000000000E+00" )
+  {
+    e.setAttribute("precision", "14");
+    e.setAttribute("format", "30");
+  }
+  else if( vf == "0.000000000000000E+00" )
+  {
+    e.setAttribute("precision", "15");
+    e.setAttribute("format", "30");
+  }
+      
+  else if( vf.upper() == "M/D/YY" )
+    e.setAttribute("format", "219");
+  else if( vf.upper() == "M/D/YYYY" )
+    e.setAttribute("format", "220");
+  else if( vf.upper() == "MM/DD/YY" )
+    e.setAttribute("format", "218");
+  else if( vf.upper() == "MM/DD/YYYY" )
+    e.setAttribute("format", "217");
+  else if( vf.upper() == "YYYY/MM/DD" )
+    e.setAttribute("format", "224");
+  else if( vf.upper() == "YYYY-MM-DD" )
+    e.setAttribute("format", "215");
+  
+  else if( vf == "h:mm AM/PM" )
+    e.setAttribute("format", "52");
+  else if( vf == "h:mm:ss AM/PM" )
+    e.setAttribute("format", "53");
+  else if( vf == "h:mm" )
+    e.setAttribute("format", "55");
+  else if( vf == "h:mm:ss" )
+    e.setAttribute("format", "56");
+  else if( vf == "[mm]:ss" )
+    e.setAttribute("format", "57");
+  else if( vf == "[h]:mm:ss" )
+    e.setAttribute("format", "58");
+  else if( vf == "[h]:mm" )
+    e.setAttribute("format", "59");
+
+  // these are not supported in KSpread, find the closest one
+  else if( vf.upper() == "YYYY/MM/D" )
+    e.setAttribute("format", "224"); // yyyy/mm/dd
+  else if( vf.upper() == "YYYY-MM-D" )
+    e.setAttribute("format", "215"); // yyyy-mm-dd
+  else if( vf == "M/D/YY h:mm" )
+    e.setAttribute("format", "219"); // m/dd/yy
+  else if( vf == "[ss]" )
+    e.setAttribute("format", "56"); // h:mm:ss
+  else if( vf == "mm:ss" )
+    e.setAttribute("format", "56"); // h:mm:ss
+  else if( vf == "mm:ss.0" )
+    e.setAttribute("format", "56"); // h:mm:ss
 
   unsigned align = 0;
   switch( format.alignment().alignX() )
   {
-    case Sidewinder::Format::Left: align = 1; break;
-    case Sidewinder::Format::Center: align = 2; break;
-    case Sidewinder::Format::Right: align = 3; break;
+    case Swinder::Format::Left: align = 1; break;
+    case Swinder::Format::Center: align = 2; break;
+    case Swinder::Format::Right: align = 3; break;
      default: align = 0; break;
   };
 
   e.setAttribute( "align", QString::number( align ) );
 
   QDomElement fontElement = doc.createElement( "font" );
-  const Sidewinder::FormatFont& font = format.font();
+  const Swinder::FormatFont& font = format.font();
   QString fontFamily = string( font.fontFamily()).string();
   double fontSize = font.fontSize();
   fontElement.setAttribute( "family", fontFamily );
@@ -123,7 +386,7 @@ QDomElement convertFormat( QDomDocument& doc, const Sidewinder::Format& format )
 
   // cell borders
 
-  const Sidewinder::FormatBorders& borders = format.borders();
+  const Swinder::FormatBorders& borders = format.borders();
 
   QDomElement leftBorderElement = doc.createElement( "left-border" );
   leftBorderElement.appendChild( convertPen( doc, borders.leftBorder() ) );
@@ -144,45 +407,102 @@ QDomElement convertFormat( QDomDocument& doc, const Sidewinder::Format& format )
   return e;
 }
 
-static QDomElement convertValue( QDomDocument& doc, const Sidewinder::Value& value )
+// see convertFormat above, this is the complementary hack
+static bool isDateFormat( const Swinder::Format& format )
+{
+  QString vf = string( format.valueFormat()).string();
+  QString vfu = vf.upper();
+  if( vfu == "M/D/YY" ) return true;
+  if( vfu == "M/D/YYYY" ) return true;
+  if( vfu == "MM/DD/YY" ) return true;
+  if( vfu == "MM/DD/YYYY" ) return true;
+  if( vfu == "YYYY/MM/D" ) return true;
+  if( vfu == "YYYY/MM/DD" ) return true;
+  if( vfu == "YYYY-MM-D" ) return true;
+  if( vfu == "YYYY-MM-DD" ) return true;
+  if( vf == "h:mm AM/PM" ) return true;
+  if( vf == "h:mm:ss AM/PM" ) return true;
+  if( vf == "h:mm" ) return true;
+  if( vf == "h:mm:ss" ) return true;
+  if( vf == "[h]:mm:ss" ) return true;
+  if( vf == "[h]:mm" ) return true;
+  if( vf == "[mm]:ss" ) return true;
+  if( vf == "M/D/YY h:mm" ) return true;
+  if( vf == "[ss]" ) return true;
+  if( vf == "mm:ss" ) return true;
+  if( vf == "mm:ss.0" ) return true;
+  
+  return false;
+}
+
+static QDomElement convertDateResult( QDomDocument& doc, const Swinder::Value& value )
+{
+  QDomText resultElement = doc.createTextNode( "result" );
+  resultElement.toElement().setAttribute( "dataType", "Date" );
+  
+  QDate dt( 1899, 12, 30 );
+  dt = dt.addDays( value.asInteger() );
+  QString str = "%1/%2/%3";
+  str = str.arg(dt.year()).arg(dt.month()).arg(dt.day());
+  resultElement.appendChild( doc.createTextNode( str ) );
+  
+  return resultElement.toElement();
+}
+
+
+// FIXME adjust formula to match KSpread
+static QDomElement convertValue( QDomDocument& doc, const Swinder::UString& formula, 
+  const Swinder::Value& value )
 {
   QDomElement textElement;
   textElement = doc.createElement( "text" );
 
+  if( !formula.isEmpty() )
+  {
+    QString str = string( formula ).string();
+    str.prepend( "=" );
+    textElement.appendChild( doc.createTextNode( str ) );
+  }
+
   if( value.isBoolean() )
   {
     textElement.setAttribute( "dataType", "Bool" );
     if( value.asBoolean() )
     {
       textElement.setAttribute( "outStr", "True" );
-      textElement.appendChild( doc.createTextNode( "true" ) );
+      if( formula.isEmpty() )
+        textElement.appendChild( doc.createTextNode( "true" ) );
     }
     else
     {
       textElement.setAttribute( "outStr", "False" );
-      textElement.appendChild( doc.createTextNode( "false" ) );
+      if( formula.isEmpty() )
+        textElement.appendChild( doc.createTextNode( "false" ) );
     }
   }
 
   else if( value.isFloat() )
   {
     textElement.setAttribute( "dataType", "Num" );
-    QString str = QString::number( value.asFloat() );
-    textElement.appendChild( doc.createTextNode( str ) );
+    QString str = QString::number( value.asFloat(), 'g', 18 );
+    if( formula.isEmpty() )
+      textElement.appendChild( doc.createTextNode( str ) );
   }
 
   else if( value.isInteger() )
   {
     textElement.setAttribute( "dataType", "Num" );
     QString str = QString::number( value.asInteger() );
-    textElement.appendChild( doc.createTextNode( str ) );
+    if( formula.isEmpty() )
+      textElement.appendChild( doc.createTextNode( str ) );
   }
 
   else if( value.isString() )
   {
     textElement.setAttribute( "dataType", "Str" );
     QString str = string( value.asString() ).string();
-    textElement.appendChild( doc.createTextNode( str ) );
+    if( formula.isEmpty() )
+      textElement.appendChild( doc.createTextNode( str.prepend('\'') ) );
   }
 
   return textElement;
@@ -269,22 +589,11 @@ KoFilter::ConversionStatus ExcelImport::convert( const QCString& from, const QCS
 
   QString inputFile = m_chain->inputFile();
 
-
-  Sidewinder::Reader *reader;
-  reader = Sidewinder::ReaderFactory::createReader( "application/msexcel" );
-
-  if( !reader )
-  {
-    KMessageBox::sorry( 0, i18n("Internal problem: format not supported." ) );
-    return KoFilter::StupidError;
-  }
-
-  Sidewinder::Workbook* workbook;
-  workbook = reader->load( inputFile.local8Bit() );
-  if( !workbook )
+  Swinder::Workbook* workbook = new Swinder::Workbook;
+  if( workbook->load( inputFile.local8Bit() ) )
   {
     KMessageBox::sorry( 0, i18n("Could not read from file." ) );
-    delete reader;
+    delete workbook;
     return KoFilter::StupidError;
   }
 
@@ -307,10 +616,12 @@ KoFilter::ConversionStatus ExcelImport::convert( const QCString& from, const QCS
 
   for( unsigned i=0; i < workbook->sheetCount(); i++ )
   {
-    Sidewinder::Sheet* sheet = workbook->sheet( i );
+    Swinder::Sheet* sheet = workbook->sheet( i );
 
     if( !sheet ) break;
 
+    kdDebug(30511) << "Importing sheet " << i+1 << " of " << workbook->sheetCount() << "\n";
+
     QDomElement table;
     table = mainDocument.createElement( "table" );
     table.setAttribute( "name", string( sheet->name() ).string() );
@@ -333,7 +644,7 @@ KoFilter::ConversionStatus ExcelImport::convert( const QCString& from, const QCS
     // columns, i.e <column>
     for( unsigned i = 0; i <= sheet->maxColumn(); i++ )
     {
-      Sidewinder::Column* column = sheet->column( i, false );
+      Swinder::Column* column = sheet->column( i, false );
       if( column )
       {
         QDomElement e;
@@ -349,7 +660,7 @@ KoFilter::ConversionStatus ExcelImport::convert( const QCString& from, const QCS
     // rows, i.e <row>
     for( unsigned i = 0; i <= sheet->maxRow(); i++ )
     {
-      Sidewinder::Row* row = sheet->row( i, false );
+      Swinder::Row* row = sheet->row( i, false );
       if( row )
       {
         QDomElement e;
@@ -366,7 +677,7 @@ KoFilter::ConversionStatus ExcelImport::convert( const QCString& from, const QCS
     for( unsigned row = 0; row <= sheet->maxRow(); row++ )
       for( unsigned col = 0; col <= sheet->maxColumn(); col++ )
       {
-        Sidewinder::Cell* cell = sheet->cell( col, row, false );
+        Swinder::Cell* cell = sheet->cell( col, row, false );
         if( cell )
         {
           QDomElement ce;
@@ -375,20 +686,29 @@ KoFilter::ConversionStatus ExcelImport::convert( const QCString& from, const QCS
           ce.setAttribute( "column", col+1 );
           table.appendChild( ce );
 
-          ce.appendChild( convertValue( mainDocument, cell->value() )  );
-
           QDomElement fe = convertFormat( mainDocument, cell->format() );
           if( cell->columnSpan() > 1 )
             fe.setAttribute( "colspan", cell->columnSpan()-1 );
           if( cell->rowSpan() > 1 )
             fe.setAttribute( "rowspan", cell->rowSpan()-1 );
+          
+          QDomElement ve = convertValue( mainDocument, cell->formula(), cell->value() );
+          
           ce.appendChild( fe );
-
+          ce.appendChild( ve );
+          
+          if( isDateFormat( cell->format() ) )
+          {
+            ve.setAttribute( "dataType", "Date" );
+            ve.appendChild( convertDateResult( mainDocument, cell->value() ) );
+          }
+            
         }
       }
 
   }
 
+      
   // prepare storage
   KoStoreDevice* out=m_chain->storageFile( "root", KoStore::Write );
 
@@ -410,7 +730,6 @@ KoFilter::ConversionStatus ExcelImport::convert( const QCString& from, const QCS
        out->close();
      }
 
-  delete reader;
   delete workbook;
 
   return KoFilter::OK;
