@@ -1,8 +1,8 @@
-// $Header: /home/kde/koffice/filters/kword/libexport/TagProcessing.cc,v 1.13 2003/07/10 06:23:38 zrusin Exp $
+//
 
 /*
    This file is part of the KDE project
-   Copyright (C) 2001, 2002 Nicolas GOUTTE <goutte@kde.org>
+   Copyright (C) 2001, 2002, 2004 Nicolas GOUTTE <goutte@kde.org>
    Copyright (c) 2001 IABG mbH. All rights reserved.
                       Contact: Wolf-Michael Bolle <Bolle@IABG.de>
 
@@ -38,20 +38,13 @@
 #include <kdebug.h>
 #include <qdom.h>
 
-#include <TagProcessing.h>
+#include "TagProcessing.h"
 
-//#define DEBUG_KWORD_TAGS
+#define DEBUG_KWORD_TAGS
+// #define DEBUG_KWORD_IGNORED_TAGS
 
 
-// The class TagProcessing and the two functions ProcessSubtags () and
-// AllowNoSubtags () allow for easing parsing of subtags in the
-// current tag. If don't expect any subtags you call AllowNoSubtags ().
-// Otherwise you create a list of TagProcessing elements and pass that
-// to ProcessSubtags () which will go through all subtags it can find,
-// call the corresponding processing function, and do all the
-// necessary error handling.
-
-void ProcessSubtags ( QDomNode                   parentNode,
+void ProcessSubtags ( const QDomNode             &parentNode,
                       QValueList<TagProcessing>  &tagProcessingList,
                       KWEFKWordLeader            *leader)
 {
@@ -79,10 +72,10 @@ void ProcessSubtags ( QDomNode                   parentNode,
                     {
                         ((*tagProcessingIt).processor) ( childNode, (*tagProcessingIt).data, leader );
                     }
-#ifdef DEBUG_KWORD_TAGS
+#ifdef DEBUG_KWORD_IGNORED_TAGS
                     else
                     {
-                        kdWarning (30508) << "Ignoring " << childNode.nodeName ()
+                        kdDebug(30508) << "Ignoring " << childNode.nodeName ()
                             << " tag in " << parentNode.nodeName () << endl;
                     }
 #endif
@@ -92,7 +85,7 @@ void ProcessSubtags ( QDomNode                   parentNode,
 
             if ( !found )
             {
-                kdWarning(30508) << "Unexpected tag " << childNode.nodeName ()
+                kdDebug(30508) << "Unexpected tag " << childNode.nodeName ()
                     << " in " << parentNode.nodeName () << "!" << endl;
             }
         }
@@ -100,30 +93,39 @@ void ProcessSubtags ( QDomNode                   parentNode,
     //kdDebug(30508) << "Ending ProcessSubtags for node: " << parentNode.nodeName() << endl;
 }
 
-#ifdef DEBUG_KWORD_TAGS
-// Version for debugging (process all sub tags)
-void AllowNoSubtags ( QDomNode myNode, KWEFKWordLeader *leader )
+void AllowNoSubtags ( const QDomNode& myNode, KWEFKWordLeader *leader )
 {
+#ifdef DEBUG_KWORD_TAGS
     QString outputText;
     QValueList<TagProcessing> tagProcessingList;
     ProcessSubtags (myNode, tagProcessingList, leader);
-}
 #else
-// Normal version: no subtags expected, so do not search any!
-void AllowNoSubtags ( QDomNode, KWEFKWordLeader* )
-{
-}
+    @_UNUSED( leader ):
 #endif
+}
 
-// The class AttrProcessing and the two functions ProcessAttributes ()
-// and AllowNoSubtags () allow for easing parsing of the current tag's
-// attributes. If don't expect any attributes you call AllowNoAttributes ().
-// Otherwise you create a list of AttrProcessing elements and pass
-// that to ProcessAttributes () which will go through all attributes
-// it can find, retrieve the value in the datatype defined, and do all
-// the necessary error handling.
+AttrProcessing::AttrProcessing ( const QString& n, const QString& t, void *d )
+    : name (n), data (d)
+{
+    if ( t == "int" )
+        type = AttrInt;
+    else if ( t == "QString" )
+        type = AttrQString;
+    else if ( t == "double" )
+        type = AttrDouble;
+    else if ( t == "bool" )
+        type = AttrBool;
+    else if ( t.isEmpty() )
+        type = AttrNull;
+    else
+    {
+        kdWarning(30508) << "Unknown type: " << t << " for element " << n << " assuming NULL" << endl;
+        type = AttrNull;
+    }
+}
 
-void ProcessAttributes ( QDomNode                     myNode,
+
+void ProcessAttributes ( const QDomNode              &myNode,
                          QValueList<AttrProcessing>  &attrProcessingList )
 {
     //kdDebug(30508) << "Starting ProcessAttributes for node: " << myNode.nodeName() << endl;
@@ -151,51 +153,61 @@ void ProcessAttributes ( QDomNode                     myNode,
 
                     if ( (*attrProcessingIt).data != NULL )
                     {
-                        if ( (*attrProcessingIt).type == "QString" )
+                        switch ( (*attrProcessingIt).type )
                         {
-                            *((QString *) (*attrProcessingIt).data) = myAttrib.value ();
-                        }
-                        else if ( (*attrProcessingIt).type == "int" )
-                        {
-                            *((int *) (*attrProcessingIt).data) = myAttrib.value ().toInt ();
-                        }
-                        else if ( (*attrProcessingIt).type == "double" )
-                        {
-                            *((double *) (*attrProcessingIt).data) = myAttrib.value ().toDouble ();
-                        }
-                        else if ( (*attrProcessingIt).type == "bool" )
-                        {
-                            QString strAttr=myAttrib.value().simplifyWhiteSpace();
-                            bool flag;
-                            if ((strAttr=="yes")||(strAttr=="1")||(strAttr=="true"))
+                        case AttrProcessing::AttrQString:
                             {
-                                flag=true;
+                                *((QString *) (*attrProcessingIt).data) = myAttrib.value ();
+                                break;
                             }
-                            else if ((strAttr=="no")||(strAttr=="0")||(strAttr=="false"))
+                        case AttrProcessing::AttrInt:
                             {
-                                flag=false;
+                                *((int *) (*attrProcessingIt).data) = myAttrib.value ().toInt ();
+                                break;
                             }
-                            else
+                        case AttrProcessing::AttrDouble:
                             {
-                                flag=false;
-                                kdWarning(30508) << "Unknown value for a boolean: " << strAttr
-                                    << " in tag " << myNode.nodeName () << ", attribute "
-                                    << myAttrib.name() << endl;
+                                *((double *) (*attrProcessingIt).data) = myAttrib.value ().toDouble ();
+                                break;
+                            }
+                        case AttrProcessing::AttrBool:
+                            {
+                                const QString strAttr ( myAttrib.value().simplifyWhiteSpace() );
+                                bool flag;
+                                if ((strAttr=="yes")||(strAttr=="1")||(strAttr=="true"))
+                                {
+                                    flag=true;
+                                }
+                                else if ((strAttr=="no")||(strAttr=="0")||(strAttr=="false"))
+                                {
+                                    flag=false;
+                                }
+                                else
+                                {
+                                    flag=false;
+                                    kdWarning(30508) << "Unknown value for a boolean: " << strAttr
+                                        << " in tag " << myNode.nodeName () << ", attribute "
+                                        << myAttrib.name() << endl;
+                                }
+                                *((bool *) (*attrProcessingIt).data) = flag;
+                                break;
+                            }
+                        case AttrProcessing::AttrNull:
+                            break;
+                        default:
+                            {
+                                kdDebug(30508) << "Unexpected data type " << int( (*attrProcessingIt).type )
+                                    << " in " << myNode.nodeName ()
+                                    << " attribute " << (*attrProcessingIt).name
+                                    << endl;
+                                break;
                             }
-                            *((bool *) (*attrProcessingIt).data) = flag;
-                        }
-                        else
-                        {
-                            kdWarning(30508) << "Unexpected data type " << (*attrProcessingIt).type
-                                << " in " << myNode.nodeName ()
-                                << " attribute " << (*attrProcessingIt).name
-                                << "!" << endl;
                         }
                     }
-#ifdef DEBUG_KWORD_TAGS
+#ifdef DEBUG_KWORD_IGNORED_TAGS
                     else
                     {
-                        kdWarning(30508) << "Ignoring " << myNode.nodeName()
+                        kdDebug(30508) << "Ignoring " << myNode.nodeName()
                             << " attribute " << (*attrProcessingIt).name
                             << endl;
                     }
@@ -214,16 +226,12 @@ void ProcessAttributes ( QDomNode                     myNode,
     //kdDebug(30508) << "Ending ProcessAttributes for node: " << myNode.nodeName() << endl;
 }
 
-#ifdef DEBUG_KWORD_TAGS
-// Version for debugging (process all attributes)
-void AllowNoAttributes ( QDomNode  myNode )
+void AllowNoAttributes ( const QDomNode & myNode )
 {
+#ifdef DEBUG_KWORD_TAGS
     QValueList<AttrProcessing> attrProcessingList;
     ProcessAttributes (myNode, attrProcessingList);
-}
 #else
-// Normal version: no attributes expected, so do not process any!
-void AllowNoAttributes ( QDomNode )
-{
-}
+    Q_UNUSED( myNode );
 #endif
+}
