@@ -38,7 +38,7 @@ class VColorTab : public QTabWidget
 public:
 	VColorTab( const VColor &c, QWidget* parent = 0L, const char* name = 0L );
 
-	VColor getColor();
+	VColor Color();
 
 private:
 	QWidget* mRGBWidget;
@@ -57,7 +57,6 @@ private:
 private slots:
 	void slotUpdateFromRGBSpinBoxes();
 	void slotUpdateFromHSVSpinBoxes();
-	void slotUpdate( const QColor &color );
 	void slotVChanged( int );
 	void slotHSChanged( int, int );
 };
