@@ -29,10 +29,16 @@
 #include <qlineedit.h>
 #include <qspinbox.h>
 #include <qbuttongroup.h>
+#include <qradiobutton.h>
+#include <qvbuttongroup.h>
 #include <kfontdialog.h>
 
+#include "kdchart/KDChartAxisParams.h"
 #include "kchart_params.h"
 
+namespace KChart
+{
+
 KChartParameterConfigPage::KChartParameterConfigPage( KChartParams* params,
                                                       QWidget* parent ) :
     QWidget( parent ),_params( params )
@@ -48,48 +54,76 @@ KChartParameterConfigPage::KChartParameterConfigPage( KChartParams* params,
     QGridLayout *grid1 = new QGridLayout(gb1->layout(),9,1);
 
     grid = new QCheckBox( i18n( "Grid" ), gb1 );
-    grid1->addWidget(grid,0,0);
-
-
-    xaxis = new QCheckBox( i18n( "X-axis" ), gb1 );
-    grid1->addWidget(xaxis,1,0);
+    grid1->addWidget(grid, 0, 0);
 
     yaxis = new QCheckBox( i18n( "Y-axis" ), gb1);
-    grid1->addWidget(yaxis,2,0);
+    connect( yaxis, SIGNAL( clicked() ), this, SLOT( axisChanged() ) );
+    grid1->addWidget(yaxis, 1, 0);
 
+    xaxis = new QCheckBox( i18n( "X-axis" ), gb1 );
+    connect( xaxis, SIGNAL( clicked() ), this, SLOT( axisChanged() ) );
+    grid1->addWidget(xaxis, 2, 0);
+
+#if 0
     xlabel = new QCheckBox( i18n( "Has X-label" ), gb1 );
     grid1->addWidget(xlabel,3,0);
 
     yaxis2 = new QCheckBox( i18n( "Y-axis 2" ), gb1 );
     grid1->addWidget(yaxis2,4,0);
+#endif
 
+#if 0 // Moved to the Line page
     lineMarker = new QCheckBox( i18n( "Line marker" ), gb1 );
-    grid1->addWidget(lineMarker,5,0);
-
+    grid1->addWidget(lineMarker, 4, 0);
+#endif
+#if 0
     llabel = new QCheckBox( i18n( "Legend" ), gb1 );
     grid1->addWidget(llabel,6,0);
+#endif
 
-    QButtonGroup* gb2 = new QButtonGroup( 0, Qt::Vertical, i18n("Title"), this );
+    QButtonGroup* gb2 = new QButtonGroup( 0, Qt::Vertical, 
+                      i18n("Settings"), this );
     gb2->layout()->setSpacing(KDialog::spacingHint());
     gb2->layout()->setMargin(KDialog::marginHint());
-    QGridLayout *grid2 = new QGridLayout(gb2->layout(),8,2);
+    QGridLayout *grid2 = new QGridLayout(gb2->layout(),8,1);
 
-    QLabel *tmpLabel = new QLabel( i18n( "Y-title:" ), gb2 );
-    grid2->addWidget(tmpLabel,2,0);
-
-    ytitle= new QLineEdit( gb2 );
-    ytitle->setMaximumWidth(130);
-    grid2->addWidget(ytitle,3,0);
-    ytitle->setEnabled(false);
-
-    tmpLabel = new QLabel( i18n( "X-title:" ), gb2 );
-    grid2->addWidget(tmpLabel,4,0);
+    QHBoxLayout * top = new QHBoxLayout( this );
+    // The X axis title
+    QLabel *tmpLabel = new QLabel( i18n( "X-title:" ), gb2 );
+    top->addWidget(tmpLabel);
+    // The Y axis title
+    tmpLabel = new QLabel( i18n( "Y-title:" ), gb2 );
+    top->addWidget(tmpLabel);
 
+    QHBoxLayout * bottom = new QHBoxLayout( this );
     xtitle= new QLineEdit( gb2 );
-    xtitle->setMaximumWidth(130);
-    grid2->addWidget(xtitle,5,0);
-    xtitle->setEnabled(false);
+    bottom->addWidget(xtitle);
+    QBoxLayout * l = new QVBoxLayout( this );
+    ytitle= new QLineEdit( gb2 );
+    bottom->addWidget(ytitle);
 
+    l->addLayout(top);
+    l->addLayout(bottom);
+    grid2->addLayout(l, 0, 0);
+
+    // Linear or logarithmic scale
+    QVButtonGroup *scaletype = new QVButtonGroup(i18n("Scale Types"), gb2);
+    lin = new QRadioButton( i18n("Linear scale"), scaletype);
+    log = new QRadioButton( i18n("Logarithmic scale"), scaletype);
+    grid2->addWidget(scaletype, 1, 0);
+
+    // Decimal precision
+    QVButtonGroup *precision = new QVButtonGroup(i18n("Precision for Numerical Left Axis"), gb2);
+    grid2->addWidget(precision, 2, 0);
+    QRadioButton * automatic_precision = new QRadioButton( i18n("Automatic precision"), precision);
+    automatic_precision->setChecked(true);
+    max = new QRadioButton( i18n("Decimal precision:"), precision);
+    connect(automatic_precision, SIGNAL(toggled(bool)), this,
+            SLOT(automatic_precision_toggled(bool)) );
+    maximum_length = new QSpinBox(0, 15, 1, precision );
+    maximum_length->setValue(2);
+
+#if 0
     tmpLabel = new QLabel( i18n( "Y-label format:" ), gb2 );
     grid2->addWidget(tmpLabel,0,1);
 
@@ -111,25 +145,29 @@ KChartParameterConfigPage::KChartParameterConfigPage( KChartParams* params,
     ylabel2_fmt= new QLineEdit( gb2 );
     ylabel2_fmt->setMaximumWidth(130);
     grid2->addWidget(ylabel2_fmt,5,1);
-
+#endif
     layout->addWidget(gb1,0,0);
     layout->addWidget(gb2,0,1);
+
+#if 0
     grid1->activate();
     grid2->activate();
-
+#endif
     /*connect( grid, SIGNAL( toggled( bool ) ),
       this, SLOT( changeState( bool ) ) );*/
     /*connect( xaxis, SIGNAL( toggled( bool ) ),
       this, SLOT( changeXaxisState( bool ) ) );*/
 }
 
-void KChartParameterConfigPage::changeXaxisState(bool state)
+
+    void KChartParameterConfigPage::changeXaxisState(bool /*state*/)
 {
+#if 0
     if(state)
         xlabel->setEnabled(true);
     else
         xlabel->setEnabled(false);
-
+#endif
 }
 
 void KChartParameterConfigPage::init()
@@ -138,23 +176,25 @@ void KChartParameterConfigPage::init()
     //     grid->setChecked(_params->grid);
     //     xlabel->setChecked(_params->hasxlabel);
 
+    grid->setChecked(_params->showGrid());
 
     xaxis->setChecked(_params->axisVisible(KDChartAxisParams::AxisPosBottom));
     yaxis->setChecked(_params->axisVisible(KDChartAxisParams::AxisPosLeft));
 
+#if 0
     llabel->setChecked(_params->legendPosition()!=KDChartParams::NoLegend);
-    grid->setChecked(_params->showGrid());
+#endif
 
-    if( _params->chartType() == KDChartParams::Line )
-    {
+#if 0
+    if ( _params->chartType() == KDChartParams::Line ) {
         lineMarker->setEnabled(true);
         lineMarker->setChecked(_params->lineMarker());
     }
-    else
-    {
+    else {
         lineMarker->setEnabled(false);
         lineMarker->setChecked(false);
     }
+#endif
 
     // PENDING(kalle) Adapt this
     //     if(_params->has_yaxis2())
@@ -166,13 +206,13 @@ void KChartParameterConfigPage::init()
     //     	ytitle2->setText(_params->ytitle2);
     //     	}
     //     else
+#if 0
     {
     	yaxis2->setEnabled(false);
     	ylabel2_fmt->setEnabled(false);
     	ytitle2->setEnabled(false);
     }
 
-
     // PENDING(kalle) Adapt this
     //     xtitle->setText(_params->xtitle);
     //     ytitle->setText(_params->ytitle);
@@ -183,19 +223,46 @@ void KChartParameterConfigPage::init()
     //     	xlabel->setEnabled(true);
     //     else
     xlabel->setEnabled(false);
+#endif
+
+    xtitle->setText( _params->axisTitle( KDChartAxisParams::AxisPosBottom) );
+    ytitle->setText( _params->axisTitle( KDChartAxisParams::AxisPosLeft) );
+    axisChanged();
+
+    // Linear / logarithmic Y axis
+    if ( _params->axisParams( KDChartAxisParams::AxisPosLeft ).axisCalcMode() ==
+                              KDChartAxisParams::AxisCalcLinear )
+	lin->setChecked(true);
+    else
+	log->setChecked(true);
+    
+     if ( _params->axisParams( KDChartAxisParams::AxisPosLeft ).axisDigitsBehindComma() ==
+            KDChartAxisParams::AXIS_LABELS_AUTO_DIGITS )
+        maximum_length->setEnabled(false);
+    else
+    {
+        max->setChecked(true);
+        maximum_length->setValue( _params->axisParams( KDChartAxisParams::AxisPosLeft ).axisDigitsBehindComma() );
+    }
 }
 
 
 void KChartParameterConfigPage::apply()
 {
-
+#if 0
     _params->setLegendPosition(llabel->isChecked() ? KDChartParams::LegendRight : KDChartParams::NoLegend);
+#endif
 
     _params->setAxisVisible(KDChartAxisParams::AxisPosBottom,xaxis->isChecked());
     _params->setAxisVisible(KDChartAxisParams::AxisPosLeft,yaxis->isChecked());
 
-    _params->setAxisShowGrid(KDChartAxisParams::AxisPosLeft,grid->isChecked() );
-    _params->setAxisShowGrid(KDChartAxisParams::AxisPosBottom,grid->isChecked() );
+    _params->setAxisShowGrid(KDChartAxisParams::AxisPosLeft,
+			     grid->isChecked() );
+    _params->setAxisShowGrid(KDChartAxisParams::AxisPosBottom,
+			     grid->isChecked() );
+
+    _params->setAxisTitle( KDChartAxisParams::AxisPosBottom, xtitle->text() );
+    _params->setAxisTitle( KDChartAxisParams::AxisPosLeft, ytitle->text() );
 
 // PENDING(kalle) Adapt this
     //     _params->border=border->isChecked();
@@ -236,6 +303,58 @@ void KChartParameterConfigPage::apply()
     //         _params->setAnnotationFont( annotationFont );
     //         }
 
+#if 0
     if( _params->chartType() == KDChartParams::Line )
         _params->setLineMarker(lineMarker->isChecked());
+#endif
+
+    // Set the scale for the Y axis (linear / logarithmic)
+    {
+	KDChartAxisParams  params
+	    = _params->axisParams( KDChartAxisParams::AxisPosLeft );
+
+        if (lin->isChecked())
+            params.setAxisCalcMode(KDChartAxisParams::AxisCalcLinear);
+        else
+        {
+            if(params.axisCalcMode() != KDChartAxisParams::AxisCalcLogarithmic)
+            {
+                // Since in this version of kdChart logarithmic scales only work for Line charts,
+                // lets switch now
+                _params->setChartType( KDChartParams::Line );
+            }
+            params.setAxisCalcMode(KDChartAxisParams::AxisCalcLogarithmic);
+        }
+
+        if ( maximum_length->isEnabled() )
+            params.setAxisDigitsBehindComma( maximum_length->value() );
+        else
+            params.setAxisDigitsBehindComma(KDChartAxisParams::AXIS_LABELS_AUTO_DIGITS );
+
+        _params->setAxisParams( KDChartAxisParams::AxisPosLeft, params );
+    }
 }
+
+void KChartParameterConfigPage::automatic_precision_toggled(bool toggled)
+{
+    if (toggled)
+        maximum_length->setEnabled(false);
+    else
+        maximum_length->setEnabled(true);
+}
+
+void KChartParameterConfigPage::axisChanged()
+{
+    if ( !xaxis->isChecked() || !yaxis->isChecked() )
+    {
+        xtitle->setEnabled( false );
+        ytitle->setEnabled( false );
+    }
+    else
+    {
+        xtitle->setEnabled( true );
+        ytitle->setEnabled( true );
+    }
+}
+
+}  //KChart namespace
