@@ -31,6 +31,7 @@
 
 #include "kformula_view.h"
 
+class KoXmlWriter;
 
 KFORMULA_NAMESPACE_BEGIN
 
@@ -60,10 +61,11 @@ public:
 
     virtual void paintContent( QPainter &painter, const QRect &rect, bool transparent = false, double zoomX = 1.0, double zoomY = 1.0 );
 
-    virtual bool initDoc();
-
+    virtual bool initDoc(InitDocFlags flags, QWidget* parentWidget=0);
+    virtual bool loadOasis( const QDomDocument& doc, KoOasisStyles& oasisStyles, const QDomDocument& settings, KoStore* );
     virtual bool loadXML(QIODevice *, const QDomDocument& doc);
     virtual QDomDocument saveXML();
+    virtual bool saveOasis( KoStore* store, KoXmlWriter* manifestWriter );
 
     KFormula::Container* getFormula() const { return formula; }
     KFormula::Document* getDocument() const { return document; }
