@@ -6,14 +6,15 @@ KivioPage *page;
 KivioView *view;
 #ifdef HAVE_PYTHON
 
+#include "kivioglobal.h"
 #include "kivio_common.h"
-#include "kivio_config.h"
 #include "kivio_connector_point.h"
 #include "kivio_connector_target.h"
 #include "kivio_fill_style.h"
 #include "kivio_intra_stencil_data.h"
 #include "kivio_line_style.h"
 #include "kivio_painter.h"
+#include "kivio_point.h"
 #include "kivio_screen_painter.h"
 #include "kivio_stencil_spawner.h"
 #include "kivio_stencil_spawner_info.h"
@@ -45,7 +46,7 @@ KivioPyStencil::KivioPyStencil()
    static bool first_time = true;
    if ( first_time ) {
      Py_Initialize();  // initialize python only once
-	 //qDebug("init kivioc");
+	 //kdDebug(43000) << "init kivioc" << endl;
      initkivioc();
      first_time = false;
    }
@@ -536,7 +537,7 @@ int KivioPyStencil::runPython(QString code)
     //const char *ccode = code.local8Bit().data();
 	const char *ccode = code.latin1();
 
-    //qDebug( "code to run:\n%s", ccode );
+    //kdDebug(43000) << "code to run:" << endl << ccode << endl;
 
     PyObject *v = PyRun_String( const_cast<char*>(ccode) , Py_file_input, globals, vars );
 
@@ -581,7 +582,7 @@ QString KivioPyStencil::getStringFromDict( PyObject *dict, const char *key )
 }
 
 
-KivioCollisionType KivioPyStencil::checkForCollision( KivioPoint *pPoint, double )
+KivioCollisionType KivioPyStencil::checkForCollision( KoPoint *pPoint, double )
 {
     double px = pPoint->x();
     double py = pPoint->y();
@@ -626,7 +627,7 @@ int KivioPyStencil::resizeHandlePositions()
  */
 void KivioPyStencil::paintConnectorTargets( KivioIntraStencilData *pData )
 {
-  QPixmap *targetPic;
+  QPixmap targetPic;
   KivioPainter *painter;
   double x, y;
 
@@ -635,7 +636,7 @@ void KivioPyStencil::paintConnectorTargets( KivioIntraStencilData *pData )
     return;
 
   // Obtain the graphic used for KivioConnectorTargets
-  targetPic = KivioConfig::config()->connectorTargetPixmap();
+  targetPic = Kivio::connectorTargetPixmap();
 
 
   KoZoomHandler* zoomHandler = pData->zoomHandler;
@@ -648,7 +649,7 @@ void KivioPyStencil::paintConnectorTargets( KivioIntraStencilData *pData )
     x = zoomHandler->zoomItX(pTarget->x());
     y = zoomHandler->zoomItY(pTarget->y());
 
-    painter->drawPixmap( x-3, y-3, *targetPic );
+    painter->drawPixmap( x-3, y-3, targetPic );
 
     pTarget = m_pConnectorTargets->next();
   }
@@ -857,7 +858,7 @@ QColor KivioPyStencil::readColor( PyObject *color )
 
 void KivioPyStencil::PyDebug( PyObject * o )
 {
-    qDebug( "py_debug : %s",  PyString_AsString(PyObject_Str(o)) );
+    kdDebug(43000) << "py_debug: " <<  PyString_AsString(PyObject_Str(o)) << endl;
 }
 
 
