@@ -913,6 +913,15 @@ void PenCmd::applyPen( KPObject *object, Pen *tmpPen )
                 //doc->repaint( obj );
             }
         } break;
+        case OT_PIE:
+        {
+            KPPieObject *obj = dynamic_cast<KPPieObject*>( object );
+            if ( obj )
+            {
+                obj->setLineBegin( tmpPen->lineBegin );
+                obj->setLineEnd( tmpPen->lineEnd );
+            }
+        } break;
         default:
             break;
     }
@@ -976,6 +985,15 @@ void PenCmd::addObjects( const QPtrList<KPObject> &_objects )
                         lineEnd = obj->getLineEnd();
                     }
                 } break;
+                case OT_PIE:
+                {
+                    KPPieObject *obj = dynamic_cast<KPPieObject*>( object );
+                    if ( obj )
+                    {
+                        lineBegin = obj->getLineBegin();
+                        lineEnd = obj->getLineEnd();
+                    }
+                } break;
                 default:
                    break;
             }
