@@ -26,22 +26,25 @@
 
 #include <qguardedptr.h>
 #include <qtimer.h>
+#include <qdatetime.h>
+#include <qpen.h>
 
 #include <koView.h>
-#include "kpresenter_doc.h"
 #include "global.h"
 #include <koRuler.h>
 
 class QPopupMenu;
+class QSplitter;
+class QLabel;
 class DCOPObject;
 class KPresenterView;
 class BackDia;
 class KoRuler;
 class QScrollBar;
 class AFChoose;
-class StyleDia;
+class PropertyEditor;
 class PgConfDia;
-class KPTransEffectDia;
+class SlideTransitionDia;
 class RotationDialogImpl;
 class ShadowDialogImpl;
 class ImageEffectDia;
@@ -59,15 +62,20 @@ class KActionMenu;
 class KToggleAction;
 class TKSelectColorAction;
 class KoPartSelectAction;
+class KoPicture;
+class KoParagStyle;
 
 class KoCharSelectDia;
 class KoTextFormat;
+class KoTextObject;
+class KoZoomHandler;
 
+class KCommand;
+class KMacroCommand;
 class KFontSizeAction;
 class KColorAction;
 class KSelectAction;
 class KFontAction;
-class KSpell;
 class KoParagCounter;
 class KActionMenu;
 class KoSearchContext;
@@ -76,8 +84,18 @@ class KPrCanvas;
 class KoFontDia;
 class KoParagDia;
 class KPPixmapObject;
+class KPresenterDoc;
+class KPrPage;
+class KPTextObject;
+class KoTextIterator;
 
-class KOSpell;
+class KoSpell;
+#ifdef HAVE_LIBKSPELL2
+#include <kspell2/broker.h>
+namespace KSpell2 {
+    class Dialog;
+}
+#endif
 
 class PageBase : public QWidget
 {
@@ -109,7 +127,6 @@ public:
     int getPresStepsOfPage() const;
     int getNumPresPages() const;
     bool gotoPresPage( int pg );
-    float getCurrentFaktor() const;
 
     virtual void setupPrinter( KPrinter &printer );
     virtual void print( KPrinter &printer );
@@ -139,14 +156,21 @@ public:
     void savePicture( KPPixmapObject* obj );
 
     void insertFile(const QString &path);
-    void configureSpellChecker();
     void testAndCloseAllTextObjectProtectedContent();
     void updateRulerInProtectContentMode();
     QPtrList<KAction> listOfResultOfCheckWord( const QString &word );
 
+#ifdef HAVE_LIBKSPELL2
+    /**
+     * Returns the KPresenter global KSpell2 Broker object.
+     */
+    KSpell2::Broker *broker() const;
+#endif
+    bool editMaster() const { return m_editMaster;}
+
 signals:
     void currentPageChanged( int );
-
+    void presentationFinished();
 
 public slots:
     // edit menu
@@ -165,6 +189,7 @@ public slots:
     // view menu
     void viewShowSideBar();
     void viewShowNoteBar();
+    void viewSlideMaster();
     void viewZoom( const QString &s );
 
     void viewFooter();
@@ -213,7 +238,7 @@ public slots:
     void toolsClosedCubicBezierCurve();
 
     // extra menu
-    void extraPenBrush();
+    void extraProperties();
     void extraRaise();
     void extraLower();
     void extraRotate();
@@ -229,6 +254,7 @@ public slots:
     void extraLineBegin();
     void extraLineEnd();
     void extraWebPres();
+    void extraMSPres();
     void extraCreateTemplate();
     void extraDefaultTemplate();
     void extraGroup();
@@ -256,8 +282,18 @@ public slots:
     void screenStop();
     void screenPause();
     void screenFirst();
-    void screenPrev();
-    void screenNext();
+    /**
+     * Go to previous step of the presentation.
+     * gotoPreviousPage: if is set to true go to beginning of the
+     *                   previous page.
+     */
+    void screenPrev( bool gotoPreviousPage = false );
+    /**
+     * Go to the next step of the presentation.
+     * gotoNextPage: if is set to true go to beginning of the
+     *               next page.
+     */
+    void screenNext( bool gotoNextPage = false );
     void screenLast();
     void screenSkip();
 
@@ -295,7 +331,7 @@ public slots:
     /**
      * Update a given item in the sidebar
      */
-    void updateSideBarItem( int pagenr, bool sticky = false );
+    void updateSideBarItem( KPrPage * page );
     void addSideBarItem( int pos );
     void moveSideBarItem( int oldPos, int newPos );
     void removeSideBarItem( int pos );
@@ -333,22 +369,21 @@ public slots:
     void addToBookmark();
     void slotSoftHyphen();
     void slotNonbreakingSpace();
+    void slotNonbreakingHyphen();
     void slotLineBreak();
+    void slotIncreaseNumberingLevel();
+    void slotDecreaseNumberingLevel();
 
     void extraAutoFormat();
-    void extraSpelling();
+    void slotSpellCheck();
 
 
-    void spellCheckerReady();
-    void spellCheckerMisspelling( const QString &, const QStringList &, unsigned int);
-    void spellCheckerCorrected( const QString &, const QString &, unsigned int);
     void spellCheckerDone( const QString & );
-    void spellCheckerFinished( );
-    void spellCheckerIgnoreAll( const QString & );
+    void spellCheckerCancel();
     void startKSpell();
-    void spellCheckerReplaceAll( const QString &, const QString & );
     void spellAddAutoCorrect (const QString & originalword, const QString & newword);
-
+    void spellCheckerMisspelling( const QString &, int );
+    void spellCheckerCorrected( const QString &, int, const QString & );
     void alignChanged( int );
 
     void formatParagraph();
@@ -423,12 +458,19 @@ public slots:
     void refreshGroupButton();
     void slotAddIgnoreAllWord();
     void addWordToDictionary();
+    void customSlideShow();
+
 public:
     // create GUI
     virtual void createGUI();
 
     // get current pagenum, 1-based
     unsigned int getCurrPgNum() const;
+    /**
+     * Recalculate the currPgNum from the activePage of the canvas
+     * This is necessary after a page has inserted.
+     */
+    void recalcCurrentPageNum();
 
     // return pointer to document
     KPresenterDoc *kPresenterDoc() const {return m_pKPresenterDoc; }
@@ -496,6 +538,7 @@ public:
 //     QColor &currColor() { return tbColor; }
 
     void enableWebPres();
+    void enableMSPres();
 
     /**
      * Overloaded from View
@@ -535,10 +578,29 @@ public:
     void penColorChanged( const QPen & _pen );
     void brushColorChanged( const QBrush & _brush );
 
-    void autoScreenPresReStartTimer();
-    void autoScreenPresIntervalTimer();
-    void autoScreenPresStopTimer();
-    void setCurrentTimer( int _currentTimer );
+    /**
+     * Restart the timer for going to the next page.
+     * This is used in automatic presentation mode.
+     */
+    void restartAutoPresTimer();
+
+    /**
+     * Continue the stopped timer for going to the next page.
+     * This is used in automatic presentation mode.
+     */
+    void continueAutoPresTimer();
+
+    /**
+     * Stop the timer for going to the next page.
+     * This is used in automatic presentation mode.
+     */
+    void stopAutoPresTimer();
+
+    /**
+     * Set the timer for going to next step to sec seconds.
+     * This is used in automatic presentation mode.
+     */
+    void setAutoPresTimer( int sec );
 
     void showCounter( KoParagCounter &c );
 
@@ -572,13 +634,12 @@ public:
     bool getPictureGrayscal() const { return grayscal; }
     int getPictureBright() const { return bright; }
 
-    int getPresentationDuration() const;
-    void setPresentationDuration( int _pgNum );
-    void restartPresentationDuration();
-
-    KPrPage * stickyPage() const;
-
-    void updatePageParameter();
+    /**
+     * Set the duration of the given page ( zero based ).
+     * This reads out m_duration and adds it to the given page.
+     * m_duration is restarted.
+     */
+    void setPageDuration( int _pgNum );
 
     void setZoomRect( const QRect & rect, bool drawRubber );
     void changeVerticalAlignmentStatus(VerticalAlignmentType _type );
@@ -589,14 +650,15 @@ public:
     void insertDirectCursor(bool b);
     void updateDirectCursorButton();
 
+    void setEditMaster( bool editMaster );
+
 protected slots:
     // dialog slots
     void backOk( BackDia*, bool );
     void afChooseOk( const QString & );
     void slotAfchooseCanceled();
-    void styleOk();
+    void propertiesOk();
     void pgConfOk();
-    void transEffectOk();
     void rotateOk();
     void shadowOk();
     void pddClosed();
@@ -648,10 +710,20 @@ protected slots:
     void extraPenWidth10();
     void setExtraPenWidth( unsigned int width );
 
-    void stopPres() {continuePres = false; }
-    void newPageLayout( KoPageLayout _layout );
+    /**
+     * Restart the presenation from the first shown slide.
+     * This only works in automatic presentation and infinite loop mode.
+     */
+    void restartPresentation() { m_autoPresRestart = true; }
+    /**
+     * Finish the automatic presentation mode.
+     * This only works in automatic presentation mode.
+     */
+    void stopAutomaticPresentation() { m_autoPresStop = true; }
+
+    void newPageLayout( const KoPageLayout &_layout );
     void openPageLayoutDia() { extraLayout(); }
-    void unitChanged( QString );
+    void unitChanged( KoUnit::Unit );
 
     void doAutomaticScreenPres();
 
@@ -684,6 +756,8 @@ protected slots:
     void editFindNext();
     void editFindPrevious();
 
+    virtual void slotChildActivated(bool a);
+
 protected:
     virtual void resizeEvent( QResizeEvent* );
     virtual void dragEnterEvent( QDragEnterEvent *e );
@@ -710,7 +784,7 @@ protected:
 
     void showParagraphDialog( int initialPage = -1, double initialTabPos = 0.0 );
 
-    void spellAddTextObject();
+    QValueList<KoTextObject *> spellAddTextObject() const;
 
     bool switchInOtherPage( const QString & text );
 
@@ -720,10 +794,19 @@ protected:
     int getZoomEntirePage() const;
 
     KCommand * applyAutoFormatToCurrentPage( const QPtrList<KoTextObject> & lst);
-    void textStyleSelected( KoStyle *_sty );
+    void textStyleSelected( KoParagStyle *_sty );
 
+    /*
+     * create a command which sets the pen according to the flags
+     * for the selected objects on the active and sticky page
+     */
+    KCommand * getPenCmd( const QString &name, QPen pen, LineEnd lb, LineEnd le, int flags );
+
+    void spellCheckerRemoveHighlight();
+
+    void updateNoteBarText();
 private:
-    void clearSpellChecker();
+    void clearSpellChecker(bool cancelSpellCheck = false);
 
 // ********** variables **********
 
@@ -731,7 +814,17 @@ private:
     KPresenterDoc *m_pKPresenterDoc;
 
     // flags
-    bool continuePres, exitPres;
+    /**
+     * Set to true if the presentation sould be restarted.
+     * This only works in automatic presentation and infinite loop mode.
+     */
+    bool m_autoPresRestart;
+
+    /**
+     * Set to true if the presentation sould be stoped.
+     * This only works in automatic presentation mode.
+     */
+    bool m_autoPresStop;
     bool m_screenSaverWasEnabled;
 
     // right button popup menus
@@ -745,9 +838,8 @@ private:
 
     // dialogs
     AFChoose *afChoose;
-    StyleDia *styleDia;
+    PropertyEditor *m_propertyEditor;
     PgConfDia *pgConfDia;
-    KPTransEffectDia *transEffectDia;
     RotationDialogImpl *rotateDia;
     ShadowDialogImpl *shadowDia;
     ImageEffectDia *imageEffectDia;
@@ -790,14 +882,15 @@ private:
     QFont tbFont;
     int tbAlign;
     QColor tbColor;
-    QStringList fontList;
 
-    bool m_bRectSelection;
-    QRect m_rctRectSelection;
-    QString m_strNewPart;
     bool m_bShowGUI;
     bool presStarted;
+    /**
+     * Indicates if the master page is edited
+     */
+    bool m_editMaster;
     bool allowWebPres;
+    bool allowMSPres;
     int currPg; // 0-based
 
     QSize oldSize;
@@ -817,10 +910,13 @@ private:
     KAction *actionEditDelete;
     KAction *actionEditSelectAll;
     KAction *actionEditDeSelectAll;
+    KAction *actionEditCopyPage;
+    KAction *actionEditDuplicatePage;
     KAction *actionEditDelPage;
 
     KToggleAction *actionViewShowSideBar;
     KToggleAction *actionViewShowNoteBar;
+    KToggleAction *actionViewSlideMaster;
 
     KToggleAction *actionViewShowHelpLine;
 
@@ -883,7 +979,7 @@ private:
     KToggleAction *actionFormatStrikeOut;
     KAction *actionTextInsertPageNum;
 
-    KAction *actionExtraPenBrush;
+    KAction *actionExtraProperties;
     KAction *actionExtraRaise;
     KAction *actionExtraLower;
 
@@ -904,6 +1000,7 @@ private:
     KAction *actionExtraLayout;
     KAction *actionExtraConfigure;
     KAction *actionExtraWebPres;
+    KAction *actionExtraMSPres;
     KAction *actionExtraCreateTemplate;
     KAction *actionExtraLineBegin;
     KAction *actionExtraLineEnd;
@@ -930,6 +1027,8 @@ private:
     KAction *actionEditFindPrevious;
     KAction *actionEditReplace;
 
+    KAction *actionCustomSlideShow;
+
     KAction *actionColorBar;
     KAction *actionExtraDefaultTemplate;
 
@@ -1049,13 +1148,20 @@ private:
 
     KAction *actionAddWordToPersonalDictionary;
 
-    QTimer automaticScreenPresTimer;
-    QTime automaticScreenPresTime;
-    int automaticScreenPresWaitTime;
-    bool automaticScreenPresFirstTimer;
-    int currentTimer;
+    /// timer for automatic presentation mode
+    QTimer m_autoPresTimer;
+    /// time for messuring the elapsed time of the timer
+    QTime m_autoPresTime;
+    /// the elapsed time if the timer gets stopped in milliseconds
+    int m_autoPresElapsedTime;
+    /// the value of m_autoPresTimer in milliseconds
+    int m_autoPresTimerValue;
+    /// true if the timer is connected to doAutomaticScreenPres
+    bool m_autoPresTimerConnected;
 
-    QTime m_presentationDuration;
+    /// timer for duration of a page
+    QTime m_duration;
+    /// list for saving the duration of the pages
     QValueList<int> m_presentationDurationList;
 
     KoCharSelectDia *m_specialCharDlg;
@@ -1093,15 +1199,21 @@ private:
 
     // Spell-checking
     struct {
-        KOSpell *kospell;
-        int spellCurrTextObjNum;
-        QPtrList<KPTextObject> textObject;
+        KoSpell *kospell;
         KMacroCommand * macroCmdSpellCheck;
         QStringList replaceAll;
-        bool bSpellSelection;
-        int selectionStartPos;
+        KoTextIterator * textIterator;
+#ifdef HAVE_LIBKSPELL2
+        KSpell2::Dialog *dlg;
+#endif
     } m_spell;
 
+#ifdef HAVE_LIBKSPELL2
+    KSpell2::Broker::Ptr m_broker;
+#endif
+
+
+
     KActionMenu *actionInsertVariable;
     KActionMenu *actionInsertCustom;
 
