@@ -86,7 +86,6 @@ KisDockerManager::KisDockerManager(KisView * view, KActionCollection * ac)
 	m_toolcontrolslider = 0;
 	m_colorslider = 0;
 
-	m_layerchanneldocker = 0;
 	m_shapesdocker = 0;
 	m_fillsdocker = 0;
 	m_toolcontroldocker = 0;
@@ -108,7 +107,6 @@ KisDockerManager::~KisDockerManager()
 	}
 
 	// make sure that the dockers get deleted
-	delete m_layerchanneldocker;
 	delete m_shapesdocker;
 	delete m_fillsdocker;
 	delete m_toolcontroldocker;
@@ -126,7 +124,7 @@ void KisDockerManager::addDockerTab(QWidget * tab, const KisID & docker, enumDoc
 			d -> plug(tab);
 		}
 		else {
-			KisDockFrameDocker * d = new KisDockFrameDocker(m_view);
+			KisDockFrameDocker * d = new KisDockFrameDocker(m_view->mainWindow());
 			d -> setCaption(docker.name());
 			m_dockWindows -> add(docker, d);
 			d -> plug(tab);
@@ -138,7 +136,7 @@ void KisDockerManager::addDockerTab(QWidget * tab, const KisID & docker, enumDoc
 			 d -> plug(tab);
 		}
 		else {
-			KoTabbedToolDock * d = new KoTabbedToolDock(m_view);
+			KoTabbedToolDock * d = new KoTabbedToolDock(m_view->mainWindow());
 			d -> setCaption(docker.name());
 			m_sliders -> add(docker, d);
 			d -> plug(tab);
@@ -150,7 +148,7 @@ void KisDockerManager::addDockerTab(QWidget * tab, const KisID & docker, enumDoc
 			d -> plug(tab);
 		}
 		else {
-			KisPaintBox * d = new KisPaintBox(m_view);
+			KisPaintBox * d = new KisPaintBox(m_view->mainWindow());
 			d -> setCaption(docker.name());
 			m_toolBoxes -> add(docker, d);
 			d -> plug(tab);
@@ -217,7 +215,7 @@ void KisDockerManager::setupDockers()
 	KisConfig cfg;
 	if ( cfg.dockerStyle() == DOCKER_SLIDER ) {
 
-		m_toolDockManager = new KoToolDockManager(m_view);
+		m_toolDockManager = new KoToolDockManager(m_view->mainWindow());
 
 		// Tools
 		m_toolcontrolslider = m_toolDockManager -> createTabbedToolDock("info");
@@ -260,10 +258,10 @@ void KisDockerManager::setupDockers()
 
 	if ( cfg.dockerStyle() == DOCKER_DOCKER ) {
 
-		m_shapesdocker = new KisDockFrameDocker(m_view);
+		m_shapesdocker = new KisDockFrameDocker(m_view->mainWindow());
 		m_shapesdocker -> setCaption(i18n("Brush Shapes"));
 
-		m_fillsdocker = new KisDockFrameDocker(m_view);
+		m_fillsdocker = new KisDockFrameDocker(m_view->mainWindow());
 		m_fillsdocker -> setCaption(i18n("Fills"));
 
 		(void)new KAction(i18n( "Hide &Shapes" ), 0, this, SLOT( viewShapesDocker() ), m_ac, "view_shapes_docker" );
@@ -272,24 +270,19 @@ void KisDockerManager::setupDockers()
 	}
 	if ( cfg.dockerStyle() == DOCKER_DOCKER || cfg.dockerStyle() == DOCKER_TOOLBOX ) {
 
-		m_toolcontroldocker = new KisDockFrameDocker(m_view);
+		m_toolcontroldocker = new KisDockFrameDocker(m_view->mainWindow());
 		m_toolcontroldocker -> setCaption(i18n("General") + "/" + i18n( "Tools" ));
 
-		m_colordocker = new KisDockFrameDocker(m_view);
+		m_colordocker = new KisDockFrameDocker(m_view->mainWindow());
 		m_colordocker -> setCaption(i18n("Color Manager"));
 
-		m_layerchanneldocker = new KisDockFrameDocker(m_view);
-		m_layerchanneldocker -> setCaption(i18n("Layers"));
-
-
-		(void)new KAction(i18n( "Hide &Layers" ), 0, this, SLOT( viewLayerChannelDocker() ), m_ac, "view_layer_docker" );
 		(void)new KAction(i18n( "Hide &Color Manager" ), 0, this, SLOT( viewColorDocker() ), m_ac, "view_color_docker" );
 		(void)new KAction(i18n( "Hide &Tool Properties" ), 0, this, SLOT( viewControlDocker() ), m_ac, "view_control_docker" );
 
 	}
 
 	// No matter what the docker style, we always have a paint box
-	m_paintboxdocker = new KisPaintBox( m_view );
+	m_paintboxdocker = new KisPaintBox( m_view->mainWindow() );
 	m_paintboxdocker -> setCaption( i18n( "Tools" ) );
 	(void)new KAction(i18n( "Hide &Tools" ), 0, this, SLOT( viewPaintBoxDocker() ), m_ac, "view_paintop_docker" );
 
@@ -316,24 +309,11 @@ void KisDockerManager::setupDockers()
 
 	connect(m_view, SIGNAL(fgColorChanged(const QColor&)), m_controlWidget, SLOT(slotSetFGColor(const QColor&)));
 	connect(m_view, SIGNAL(bgColorChanged(const QColor&)), m_controlWidget, SLOT(slotSetBGColor(const QColor&)));
-#if 0
-	// ---------------------------------------------------------------------
-	// Bird's eye box
-	m_birdEyeBox = new KisBirdEyeBox(m_toolcontroldocker);
-	m_birdEyeBox -> setCaption(i18n("Overview"));
-
-	if ( cfg.dockerStyle() == DOCKER_SLIDER ) {
-		m_toolcontrolslider -> plug ( m_birdEyeBox );
-	}
-	else {
-		m_toolcontroldocker -> plug(m_birdEyeBox);
-	}
-#endif 
 
 	// ---------------------------------------------------------------------
 	// Layers
 
-	m_layerBox = new KisLayerBox(i18n("Layer"), KisLayerBox::SHOWALL, m_layerchanneldocker);
+	m_layerBox = new KisLayerBox(i18n("Layer"), KisLayerBox::SHOWALL, m_toolcontroldocker);
 	m_layerBox -> setCaption(i18n("Layers"));
 
 	connect(m_layerBox, SIGNAL(itemToggleVisible()), m_view, SLOT(layerToggleVisible()));
@@ -359,21 +339,9 @@ void KisDockerManager::setupDockers()
 		m_layerchannelslider -> plug( m_layerBox );
 	}
 	else {
-		m_layerchanneldocker -> plug(m_layerBox);
+		m_toolcontroldocker -> plug(m_layerBox);
 	}
 
-#if 0	// This doesn't do anything useful yet.
-	// Channels
-	m_channelView = new KisChannelView(m_view -> document(), m_view);
-	m_channelView -> setCaption(i18n("Channels"));
-	if ( cfg.dockerStyle() == DOCKER_SLIDER ) {
-		m_layerchannelslider -> plug( m_channelView );
-	}
-	else {
-		m_layerchanneldocker -> plug(m_channelView);
-	}
-#endif
-
 	// ---------------------------------------------------------------------
 	// Shapes
 
@@ -493,7 +461,7 @@ void KisDockerManager::setupDockers()
 	// Colors
 
 
-	m_hsvwidget = new KisHSVWidget(m_view, "hsv");
+	m_hsvwidget = new KisHSVWidget(m_view->mainWindow(), "hsv");
 	m_hsvwidget -> setCaption(i18n("HSV"));
 	if ( cfg.dockerStyle() == DOCKER_SLIDER ) {
 		m_colorslider -> plug( m_hsvwidget );
@@ -523,7 +491,7 @@ void KisDockerManager::setupDockers()
 	}
 	m_view -> attach(m_graywidget);
 
-	m_palettewidget = new KisPaletteWidget(m_view);
+	m_palettewidget = new KisPaletteWidget(m_view -> mainWindow());
 	m_palettewidget -> setCaption(i18n("Palettes"));
 
 	connect(rserver, SIGNAL(loadedPalette(KisResource*)), m_palettewidget, SLOT(slotAddPalette(KisResource*)));
@@ -537,25 +505,15 @@ void KisDockerManager::setupDockers()
 		m_colordocker -> plug(m_palettewidget);
 	}
 
-
-#if 0
-	// Filters XXX: Disable for the release.
-	m_filterBox = new KisFilterBox(m_view, m_view, "filter box");
-	m_paintboxdocker -> plug( m_filterBox, "Painting filters" );
-	m_filterBox -> init();
-#endif
-
 	if ( cfg.dockerStyle() == DOCKER_DOCKER || cfg.dockerStyle() == DOCKER_TOOLBOX ) {
 		// TODO Here should be a better check
 		if ( m_view -> mainWindow() -> isDockEnabled( DockBottom)) {
 			m_view -> mainWindow()->addDockWindow( m_toolcontroldocker, DockRight );
-			m_view -> mainWindow()->addDockWindow( m_layerchanneldocker, DockRight );
 			m_view -> mainWindow()->addDockWindow( m_colordocker, DockRight );
 			m_view -> mainWindow()->addDockWindow( m_paintboxdocker, DockRight );
 
 
 			m_toolcontroldocker -> show();
-			m_layerchanneldocker -> show();
 			m_paintboxdocker -> show();
 			m_colordocker -> show();
 
@@ -632,19 +590,6 @@ void KisDockerManager::viewControlDocker()
 	}
 }
 
-void KisDockerManager::viewLayerChannelDocker()
-{
-	if ( m_layerchanneldocker->isVisible() == false )
-	{
-		m_layerchanneldocker->show();
-		((KAction*)m_ac->action("view_layer_docker")) -> setText(i18n("Hide &Layers"));
-	}
-	else {
-		m_layerchanneldocker -> hide();
-		((KAction*)m_ac->action("view_layer_docker")) -> setText(i18n("Show &Layers"));
-	}
-}
-
 void KisDockerManager::viewFillsDocker()
 {
 	if( m_fillsdocker->isVisible() == false )
@@ -725,6 +670,9 @@ void KisDockerManager::slotPatternChanged(KisPattern * pattern)
 
 void KisDockerManager::resetLayerBox(KisImageSP img, KisLayerSP layer)
 {
+	if (!img) return;
+	if (!layer) return;
+
 	m_layerBox -> setUpdatesEnabled(false);
 	m_layerBox -> clear();
 
