@@ -124,6 +124,7 @@
 
 KisView::KisView(KisDoc *doc, KisUndoAdapter *adapter, QWidget *parent, const char *name) : super(doc, parent, name)
 {
+        setFocusPolicy( QWidget::StrongFocus );
 	// XXX Temporary re-instatement of old way to load filters and tools
 	m_toolRegistry = new KisToolRegistry();
 	Q_CHECK_PTR(m_toolRegistry);
@@ -441,7 +442,7 @@ void KisView::resizeEvent(QResizeEvent *)
 
 	drawH = height() - rulerThickness;
 	drawW = width() - rulerThickness;
-	
+
 	if (drawH < docH) {
 		// Will need vert scrollbar
 		drawW -= scrollBarExtent;
@@ -526,7 +527,9 @@ void KisView::resizeEvent(QResizeEvent *)
 	}
 
 	m_vScroll -> setPageStep(drawH);
+	m_vScroll -> setLineStep(drawH/4);
 	m_hScroll -> setPageStep(drawW);
+	m_hScroll -> setLineStep(drawW/4);
 
 	if (m_vScroll -> isVisible())
 		m_vRuler -> updateVisibleArea(0, m_vScroll -> value());
@@ -552,9 +555,11 @@ void KisView::updateReadWrite(bool readwrite)
 
 void KisView::clearCanvas(const QRect& rc)
 {
-	QPainter gc(&m_canvasPixmap);
+	QPainter gc;
 
-	gc.fillRect(rc, backgroundColor());
+	if (gc.begin(&m_canvasPixmap)) {
+		gc.fillRect(rc, backgroundColor());
+	}
 }
 
 void KisView::setCurrentTool(KisTool *tool)
@@ -698,38 +703,40 @@ void KisView::paintView(const KisRect& r)
 
 		if (!vr.isNull()) {
 
-			QPainter gc(&m_canvasPixmap);
-			QRect wr = viewToWindow(vr).qRect();
+			QPainter gc;
 
-			if (wr.left() < 0 || wr.right() >= img -> width() || wr.top() < 0 || wr.bottom() >= img -> height()) {
-				// Erase areas outside document
-				QRegion rg(vr.qRect());
-				rg -= QRegion(windowToView(KisRect(0, 0, img -> width(), img -> height())).qRect());
+			if (gc.begin(&m_canvasPixmap)) {
+				QRect wr = viewToWindow(vr).qRect();
 
-				QMemArray<QRect> rects = rg.rects();
+				if (wr.left() < 0 || wr.right() >= img -> width() || wr.top() < 0 || wr.bottom() >= img -> height()) {
+					// Erase areas outside document
+					QRegion rg(vr.qRect());
+					rg -= QRegion(windowToView(KisRect(0, 0, img -> width(), img -> height())).qRect());
 
-				for (unsigned int i = 0; i < rects.count(); i++) {
-					QRect er = rects[i];
-					if (er.isValid())
-						gc.fillRect(er, backgroundColor());
+					QMemArray<QRect> rects = rg.rects();
+
+					for (unsigned int i = 0; i < rects.count(); i++) {
+						QRect er = rects[i];
+						if (er.isValid())
+							gc.fillRect(er, backgroundColor());
+					}
+
+					wr &= QRect(0, 0, img -> width(), img -> height());
 				}
 
-				wr &= QRect(0, 0, img -> width(), img -> height());
-			}
+				if (!wr.isNull()) {
 
-			if (!wr.isNull()) {
+					if (zoom() < 1.0 || zoom() > 1.0) {
+						gc.setViewport(0, 0, static_cast<Q_INT32>(m_canvasPixmap.width() * zoom()), static_cast<Q_INT32>(m_canvasPixmap.height() * zoom()));
+					}
+					gc.translate((-horzValue()) / zoom(), (-vertValue()) / zoom());
 
-				if (zoom() < 1.0 || zoom() > 1.0) {
-					gc.setViewport(0, 0, static_cast<Q_INT32>(m_canvasPixmap.width() * zoom()), static_cast<Q_INT32>(m_canvasPixmap.height() * zoom()));
+					m_doc -> setCurrentImage(img);
+					m_doc -> paintContent(gc, wr, monitorProfile());
+					m_doc -> setCurrentImage(0);
 				}
-				gc.translate((-horzValue()) / zoom(), (-vertValue()) / zoom());
-
-				m_doc -> setCurrentImage(img);
-				m_doc -> paintContent(gc, wr, monitorProfile());
-				m_doc -> setCurrentImage(0);
 			}
 
-
 			m_canvas -> update(vr.qRect());
 		}
 	} else {
@@ -798,7 +805,7 @@ void KisView::layerUpdateGUI(bool enable)
 	m_layerLower -> setEnabled(enable && nlayers > 1 && layerPos != nlayers - 1);
 	m_layerTop -> setEnabled(enable && nlayers > 1 && layerPos);
 	m_layerBottom -> setEnabled(enable && nlayers > 1 && layerPos != nlayers - 1);
-	
+
 	// XXX thes should be named layer instead of img
 	m_imgFlatten -> setEnabled(nlayers > 1);
 
@@ -1557,7 +1564,7 @@ void KisView::print(KPrinter& printer)
 
 	if (printerProfile != 0)
 		kdDebug() << "Printer profile: " << printerProfile -> productName() << "\n";
-	
+
 	QRect r = img -> bounds();
 	img -> renderToPainter(r.x(), r.y(), r.width(), r.height(), gc, printerProfile);
 }
@@ -2161,7 +2168,7 @@ void KisView::scrollV(int value)
 void KisView::setupCanvas()
 {
 	m_canvas = new KisCanvas(this, "kis_canvas");
-
+        m_canvas->setFocusPolicy( QWidget::StrongFocus );
 	QObject::connect(m_canvas, SIGNAL(gotButtonPressEvent(KisButtonPressEvent*)), this, SLOT(canvasGotButtonPressEvent(KisButtonPressEvent*)));
 	QObject::connect(m_canvas, SIGNAL(gotButtonReleaseEvent(KisButtonReleaseEvent*)), this, SLOT(canvasGotButtonReleaseEvent(KisButtonReleaseEvent*)));
 	QObject::connect(m_canvas, SIGNAL(gotDoubleClickEvent(KisDoubleClickEvent*)), this, SLOT(canvasGotDoubleClickEvent(KisDoubleClickEvent*)));
