@@ -1,8 +1,35 @@
+/* This file is part of the KDE project
+   
+   Copyright 2004 Ariya Hidayat <ariya@kde.org>
+   Copyright 2002-2003 Joseph Wenninger <jowenn@kde.org>
+   Copyright 2002 John Dailey <dailey@vt.edu>
+   Copyright 2001-2002 Laurent Montel <montel@kde.org>
+   Copyright 2001 Philipp Mueller <philipp.mueller@gmx.de>
+   Copyright 2000 Simon Hausmann <hausmann@kde.org>
+   Copyright 1999 Torben Weis <weis@kde.org>
+
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
+
 #include "KSpreadViewIface.h"
 
 #include "kspread_view.h"
 #include "kspread_doc.h"
 #include "kspread_map.h"
+#include "kspread_selection.h"
 
 #include <kapplication.h>
 #include <dcopclient.h>
@@ -34,9 +61,9 @@ DCOPRef KSpreadViewIface::map() const
     return DCOPRef( kapp->dcopClient()->appId(), m_view->doc()->map()->dcopObject()->objId() );
 }
 
-DCOPRef KSpreadViewIface::table() const
+DCOPRef KSpreadViewIface::sheet() const
 {
-    return DCOPRef( kapp->dcopClient()->appId(), m_view->activeTable()->dcopObject()->objId() );
+    return DCOPRef( kapp->dcopClient()->appId(), m_view->activeSheet()->dcopObject()->objId() );
 }
 
 void KSpreadViewIface::changeNbOfRecentFiles(int _nb)
@@ -102,19 +129,19 @@ void KSpreadViewIface::preference()
     m_view->preference();
 }
 
-void KSpreadViewIface::nextTable()
+void KSpreadViewIface::nextSheet()
 {
-    m_view->nextTable();
+    m_view->nextSheet();
 }
 
-bool KSpreadViewIface::showTable(QString tableName)
+bool KSpreadViewIface::showSheet(QString sheetName)
 {
-   return m_view->showTable(tableName);
+   return m_view->showSheet(sheetName);
 }
 
-void KSpreadViewIface::previousTable()
+void KSpreadViewIface::previousSheet()
 {
-    m_view->previousTable();
+    m_view->previousSheet();
 }
 
 void KSpreadViewIface::sortList()
@@ -260,7 +287,7 @@ void KSpreadViewIface::copyAsText()
 void KSpreadViewIface::setSelection(QRect selection)
 {
   m_view->selectionInfo()->setSelection(selection.topLeft(), selection.bottomRight(),
-                                        m_view->activeTable());
+                                        m_view->activeSheet());
 }
 
 QRect KSpreadViewIface::selection()
@@ -285,7 +312,7 @@ void KSpreadViewIface::setSelectionPercent( bool b )
 
 void KSpreadViewIface::setSelectionMultiRow( bool enable )
 {
-  m_view->multiRow(enable);
+  m_view->wrapText(enable);
 }
 
 void KSpreadViewIface::setSelectionSize(int size)
