@@ -31,6 +31,7 @@
 #include <klocale.h>
 #include <kprinter.h>
 
+#include "koGlobal.h"
 #include "bracketelement.h"
 #include "contextstyle.h"
 #include "formulacursor.h"
@@ -348,7 +349,7 @@ void Container::paste()
     }
 }
 
-void Container::paste( QDomDocument document, QString desc )
+void Container::paste( const QDomDocument& document, QString desc )
 {
     FormulaCursor* cursor = activeCursor();
     QPtrList<BasicElement> list;
@@ -480,8 +481,16 @@ void Container::setFontSizeDirect( int pointSize )
     recalc();
 }
 
+void Container::updateMatrixActions()
+{
+    BasicElement *currentElement = activeCursor()->getElement();
+    if ( ( currentElement = currentElement->getParent() ) != 0 )
+        document()->wrapper()->enableMatrixActions( dynamic_cast<MatrixElement*>(currentElement) );
+    else
+        document()->wrapper()->enableMatrixActions( false );
+}
 
-void Container::save( QDomElement root )
+void Container::save( QDomElement &root )
 {
     QDomDocument ownerDoc = root.ownerDocument();
     root.appendChild(rootElement()->getElementDom(ownerDoc));
@@ -491,7 +500,7 @@ void Container::save( QDomElement root )
 /**
  * Loads a formula from the document.
  */
-bool Container::load( QDomElement fe )
+bool Container::load( const QDomElement &fe )
 {
     if (!fe.isNull()) {
         FormulaElement* root = createMainSequence();
@@ -515,21 +524,35 @@ bool Container::load( QDomElement fe )
 }
 
 
-void Container::saveMathML( QTextStream& stream )
+void Container::saveMathML( QTextStream& stream, bool oasisFormat )
 {
-    QDomDocumentType dt = QDomImplementation().createDocumentType( "math",
-                                             "-//W3C//DTD MathML 2.0//EN",
-                          "http://www.w3.org/TR/MathML2/dtd/mathml2.dtd");
-    QDomDocument doc( dt );
-    rootElement()->writeMathML( doc, doc );
-    doc.save( stream, 2 );
+    if ( !oasisFormat )
+    {
+        // ### TODO: Are we really using MathML 2.0 or would be MathMl 1.01 enough (like for OO)?
+        QDomDocumentType dt = QDomImplementation().createDocumentType( "math",
+                                                                       "-//W3C//DTD MathML 2.0//EN",
+                                                                       "http://www.w3.org/TR/MathML2/dtd/mathml2.dtd");
+        QDomDocument doc( dt );
+        doc.insertBefore( doc.createProcessingInstruction( "xml", "version=\"1.0\" encoding=\"UTF-8\"" ), doc.documentElement() );
+        rootElement()->writeMathML( doc, doc, oasisFormat );
+        stream << doc;
+    }
+    else
+    {
+        QDomDocument doc;
+        rootElement()->writeMathML( doc, doc, oasisFormat );
+        stream << doc;
+    }
 }
 
-bool Container::loadMathML( QDomDocument doc )
+bool Container::loadMathML( const QDomDocument &doc, bool oasisFormat )
 {
     const ContextStyle& context = document()->getContextStyle();
-    MathML2KFormula filter( doc, context );
+    MathML2KFormula filter( doc, context, oasisFormat );
     filter.startConversion();
+    if (filter.m_error) {
+        return false;
+    }
 
     if ( load( filter.getKFormulaDom().documentElement() ) ) {
         getHistory()->clear();
@@ -565,7 +588,7 @@ QImage Container::drawImage( int width, int height )
                      static_cast<double>( height )/static_cast<double>( realHeight ) );
 
     int oldZoom = context.zoom();
-    context.setZoomAndResolution( qRound( oldZoom*f ), QPaintDevice::x11AppDpiX(), QPaintDevice::x11AppDpiY() );
+    context.setZoomAndResolution( qRound( oldZoom*f ), KoGlobal::dpiX(), KoGlobal::dpiY() );
 
     kdDebug( DEBUGID ) << "Container::drawImage "
                        << "(" << width << " " << height << ")"
@@ -579,7 +602,7 @@ QImage Container::drawImage( int width, int height )
     QPainter paint(&pm);
     impl->rootElement->draw(paint, rect, context);
     paint.end();
-    context.setZoomAndResolution( oldZoom, QPaintDevice::x11AppDpiX(), QPaintDevice::x11AppDpiY() );
+    context.setZoomAndResolution( oldZoom, KoGlobal::dpiX(), KoGlobal::dpiY() );
     //return pm.convertToImage().smoothScale( width, height );
     return pm.convertToImage();
 }
