@@ -40,6 +40,7 @@ class Container;
 class ContextStyle;
 class SymbolAction;
 class SymbolTable;
+class DocumentWrapper;
 
 
 /**
@@ -63,7 +64,7 @@ protected:
  * bother to ask the document. It's legal to directly create
  * or destroy a Container object.
  */
-class Document : public QObject {
+class KOFORMULA_EXPORT Document : public QObject {
     Q_OBJECT
 
     friend class DocumentWrapper;
@@ -106,8 +107,14 @@ public:
      * Load a kformula DomDocument with all its formulas.
      * This must only be called on a virgin document.
      */
-    bool loadXML( QDomDocument doc );
+    bool loadXML( const QDomDocument& doc );
 
+    /**
+     * Load a OASIS content.xml DomDocument
+     * @since 1.4
+     */
+    bool loadOasis( const QDomDocument& doc );
+    
     /**
      * Load the document settings.
      */
@@ -121,7 +128,7 @@ public:
     /**
      * Save the document settings.
      */
-    QDomElement saveDocumentPart( QDomDocument doc );
+    QDomElement saveDocumentPart( QDomDocument& doc );
 
 
     /**
@@ -261,7 +268,7 @@ private:
  * A Wrapper that constracts the actions and must be given a real
  * document to work with.
  */
-class DocumentWrapper : public QObject {
+class KOFORMULA_EXPORT DocumentWrapper : public QObject {
     Q_OBJECT
 
 public:
@@ -279,6 +286,11 @@ public:
      */
     Document* document() const { return m_document; }
 
+    /**
+     * Enables our action according to enabled.
+     */
+    void setEnabled( bool enabled );
+
     /**
      * Inserts the document we are wrapping. This must be called once
      * before the wrapper can be used.
@@ -321,6 +333,7 @@ public:
     KAction* getInsertRowAction()        { return m_insertRowAction; }
     KAction* getRemoveRowAction()        { return m_removeRowAction; }
 
+    void enableMatrixActions(bool);
     KSelectAction* getLeftBracketAction()  { return m_leftBracket; }
     KSelectAction* getRightBracketAction() { return m_rightBracket; }
     SymbolAction* getSymbolNamesAction()  { return m_symbolNamesAction; }
