@@ -31,13 +31,13 @@
 class KURL;
 
 class KoStore;
-
+class KoXmlWriter;
 
 /**
  * A collection of pictures (a key and the picture itself).
  *
  */
-class KoPictureCollection : public QMap<KoPictureKey, KoPicture>
+class KOFFICECORE_EXPORT KoPictureCollection : public QMap<KoPictureKey, KoPicture>
 {
 public:
     enum Type {
@@ -50,7 +50,7 @@ public:
     };
 
     /**
-     * Looks for a clipart in the collection, returns 0L if not found.
+     * Looks for a clipart in the collection, returns a new KoPicture with that key if not found.
      */
     KoPicture findPicture( const KoPictureKey &key ) const;
 
@@ -66,14 +66,19 @@ public:
     KoPicture insertPicture( const KoPicture& picture );
 
     /**
-     * Download a possibly remote file
+     * @brief Download a possibly remote file
+     *
      * If this file is really remote, it is always downloaded.
      * If the file is local, it acts as @ref #loadPicture.
+     * @param url the URL to download from
+     * @param window the parent window for the download. You can pass NULL (0)
+     *               if you absolutely cannot find anything to use.
      */
-    KoPicture downloadPicture(const KURL& url);
+    KoPicture downloadPicture(const KURL& url, QWidget *window);
 
     /**
-     * Load a clipart from a file (and insert into the collection).
+     * @brief Load a clipart from a file (and insert into the collection).
+     *
      * The modification date of the file is checked, to create the key
      * for this clipart. If this key maps to an existing clipart in the
      * collection, then this picture is returned, otherwise the file is loaded.
@@ -100,7 +105,7 @@ public:
     bool saveToStoreAsKOffice1Dot1(const Type pictureType, KoStore * store, QValueList<KoPictureKey> keys );
 
     /**
-     * Generate the <PIXMAPS> or <CLIPARTS> tag, that saves the key and the related
+     * Generate the &lt;PICTURES&gt;, &lt;PIXMAPS> or &lt;CLIPARTS> tag, that saves the key and the related
      * relative path in the store (e.g. pictures/picture1.png) for each picture.
      *
      * @param pictureType the type of the collection
@@ -112,13 +117,16 @@ public:
 
     void saveXMLAsKOffice1Dot1(QDomDocument &doc, QDomElement& parent, QValueList<KoPictureKey> keys);
 
+    bool saveOasisToStore( KoStore *store, QValueList<KoPictureKey> keys, KoXmlWriter* manifestWriter );
+
+
     typedef QMap<KoPictureKey, QString> StoreMap;
     /**
-     * Read the <PIXMAPS> or <CLIPARTS> tag, and save the result (key<->store-filename associations)
+     * Read the &lt;PICTURES&gt;, &lt;PIXMAPS> or &lt;CLIPARTS> tag, and save the result (key<->store-filename associations)
      * into the QMap. You may want to 'new' a QMap in loadXML, and to use and then delete
      * it in completeLoading (to save memory).
      *
-     * @param pixmapsElem the <PIXMAPS> or <CLIPARTS> element
+     * @param pixmapsElem the &lt;PICTURES&gt;, &lt;PIXMAPS> or &lt;CLIPARTS> element
      */
     StoreMap readXML( QDomElement &pixmapsElem );
 
@@ -140,12 +148,24 @@ public:
      * for loading images from disk.
      *
      * @param fileName the name of the file to read from disk if needed
-     * @param the date and time
+     * @param dateTime the date and time
      *
      * Formerly, an invalid date/time meant to read the file from disk. This is not the case anymore.
      */
     KoPicture findOrLoad(const QString& fileName, const QDateTime& dateTime);
 
+    /**
+     * Return filename as url for picture
+     *
+     */
+    QString getOasisFileName(const KoPicture& picture) const;
+
+    /**
+     * Call it before to save Oasis file
+     */
+    void assignUniqueIds();
+
+
 private:
     /**
      * @internal
