@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 David Faure <faure@kde.org>
+   Copyright (C) 2001-2005 David Faure <faure@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,8 +24,15 @@
 #include "koChangeCaseDia.h"
 #include "kostyle.h"
 #include "kotextdocument.h"
+#include <koffice_export.h>
+
+class KoSavingContext;
 class KCommand;
 class KoTextFormat;
+class QProgressDialog;
+class KoLinkVariable;
+class KoVariable;
+
 //#define TIMING_FORMAT
 //#include <qdatetime.h>
 
@@ -38,10 +45,11 @@ class KoTextFormat;
  * it's possible to implement "setBold", "setItalic" etc. only once, whether it applies
  * to a text selection or to complete text objects.
  */
-class KoTextFormatInterface
+class KOTEXT_EXPORT KoTextFormatInterface
 {
 public:
     KoTextFormatInterface() {}
+    virtual ~KoTextFormatInterface() {}
 
     /** Interface for accessing the current format */
     virtual KoTextFormat * currentFormat() const = 0;
@@ -165,17 +173,22 @@ public:
  * the undo/redo commands).
  * Editing the text isn't done by KoTextObject but by KoTextView (document/view design).
  */
-class KoTextObject : public QObject, public KoTextFormatInterface
+class KOTEXT_EXPORT KoTextObject : public QObject, public KoTextFormatInterface
 {
     Q_OBJECT
 public:
     /** Constructor.
      * @param the zoom handler (to be passed to the KoTextDocument ctor)
-     * @param defaultFont the font to use by default (@see KoTextFormatCollection)
+     * @param defaultFont the font to use by default (see KoTextFormatCollection)
+     * @param defaultLanguage the language to use by default (see KoTextFormatCollection)
+     * @param defaultHyphenation the default setting for hyphenation (see KoTextFormatCollection)
      * @param defaultStyle the style to use by default (initial pararaph, and when deleting a used style)
+     * @param tabStopWidth the global value for the tabstop width
+     *
      * This constructor creates the contained KoTextDocument automatically.
      */
-    KoTextObject( KoZoomHandler *zh, const QFont& defaultFont, const QString &defaultLanguage, bool hyphen, double ulw, KoStyle* defaultStyle,int _tabStopWidth = -1,
+    KoTextObject( KoZoomHandler *zh, const QFont& defaultFont, const QString &defaultLanguage,
+                  bool defaultHyphenation, KoParagStyle* defaultStyle, int tabStopWidth = -1,
                   QObject* parent = 0, const char *name = 0 );
 
     /** Alternative constructor.
@@ -184,12 +197,17 @@ public:
      * @param defaultStyle the style to use by default (initial pararaph, and when deleting a used style)
      * This constructor allows to use a derived class from KoTextDocument.
      */
-    KoTextObject( KoTextDocument *textdoc, KoStyle* defaultStyle,
+    KoTextObject( KoTextDocument *textdoc, KoParagStyle* defaultStyle,
                   QObject* parent = 0, const char *name = 0 );
 
     virtual ~KoTextObject();
 
 
+    static const char * acceptSelectionMimeType();
+    /// Check if the mimesource @p mime provides one of the OASIS mimetypes,
+    /// and if so, return it. Otherwise return an empty string.
+    static QCString providesOasis( QMimeSource* mime );
+
     void setNeedSpellCheck(bool b);
     bool needSpellCheck() const { return m_needsSpellCheck;}
     void setProtectContent(bool b) { m_protectContent = b; }
@@ -242,7 +260,8 @@ public:
                              const QString & cmdName = QString::null, bool createUndoRedo=true  );
 
     KCommand * replaceSelectionCommand( KoTextCursor * cursor, const QString & replacement,
-                                        int selectionId, const QString & cmdName, bool repaint = true );
+                                        int selectionId, const QString & cmdName, bool repaint = true,
+                                        bool checkNewLine = true );
     KCommand * removeSelectedTextCommand( KoTextCursor * cursor, int selectionId, bool repaint = true );
     KCommand* insertParagraphCommand( KoTextCursor * cursor );
 
@@ -264,7 +283,7 @@ public:
 
     /** Selections ids */
     enum SelectionIds {
-        HighlightSelection = 1 // used to highlight during search/replace
+        HighlightSelection = 2 // used to highlight during search/replace
     };
 
     enum KeyboardAction { // keep in sync with QTextEdit
@@ -288,16 +307,16 @@ public:
     KCommand * setParagDirectionCommand( KoTextCursor * cursor, QChar::Direction d, int selectionId = KoTextDocument::Standard );
 
     /**
-     * Apply a KoStyle to a selection.
+     * Apply a KoParagStyle to a selection.
      * @param cursor the current cursor; used if there is no selection. Can be 0L if there is one.
-     * @param style the KoStyle to apply
+     * @param style the KoParagStyle to apply
      * @param selectionId the id of the selection, usually Standard or Temp
      * @param paragLayoutFlags which settings from the paragraph layout to apply
      * @param formatFlags which settings from the text format to apply
      * @param createUndoRedo if true, an undo/redo command will be created and emitted
      * @param interactive if true, the text will be reformatted/repainted to show the new style
      */
-    void applyStyle( KoTextCursor * cursor, const KoStyle * style,
+    void applyStyle( KoTextCursor * cursor, const KoParagStyle * style,
                      int selectionId = KoTextDocument::Standard,
                      int paragLayoutFlags = KoParagLayout::All, int formatFlags = KoTextFormat::Format,
                      bool createUndoRedo = true, bool interactive = true );
@@ -307,7 +326,7 @@ public:
      * e.g. to put it into a macro-command.
      * @return the command for 'apply style', or 0L if createUndoRedo is false.
      */
-    KCommand* applyStyleCommand( KoTextCursor * cursor, const KoStyle * style,
+    KCommand* applyStyleCommand( KoTextCursor * cursor, const KoParagStyle * style,
                      int selectionId = KoTextDocument::Standard,
                      int paragLayoutFlags = KoParagLayout::All, int formatFlags = KoTextFormat::Format,
                      bool createUndoRedo = true, bool interactive = true );
@@ -318,7 +337,7 @@ public:
      *  @param paragLayoutChanged paragraph flags
      *  @param formatChanged format flags
      */
-    void applyStyleChange( StyleChangeDefMap changed );
+    void applyStyleChange( KoStyleChangeDefMap changed );
     /** Set format changes on selection or current cursor.
         Creates a command if the format was applied to a selection */
     void setFormat( KoTextCursor * cursor, KoTextFormat ** currentFormat, KoTextFormat *format, int flags, bool zoomFont = false );
@@ -344,8 +363,9 @@ public:
     virtual KCommand *setParagLayoutFormatCommand( KoParagLayout *newLayout, int flags, int marginIndex=-1);
 
     // common for setParagLayoutFormatCommand above and KoTextView::setParagLayoutFormatCommand
-    KCommand *setParagLayoutFormatCommand( KoTextCursor* cursor, int selectionId, KoParagLayout *newLayout, int flags, int marginIndex );
-
+    KCommand *setParagLayoutCommand( KoTextCursor * cursor, const KoParagLayout& paragLayout,
+                                     int selectionId, int paragLayoutFlags,
+                                     int marginIndex, bool createUndoRedo );
     /**
      * Support for changing the format in the whole textobject
      */
@@ -391,10 +411,34 @@ public:
     QString textChangedCase(const QString& _text, KoChangeCaseDia::TypeOfCase _type);
     KCommand *changeCaseOfTextParag(int cursorPosStart, int cursorPosEnd,KoChangeCaseDia::TypeOfCase _type,KoTextCursor *cursor, KoTextParag *parag);
 
+    void loadOasisContent( const QDomElement &bodyElem, KoOasisContext& context, KoStyleCollection * styleColl );
+    void saveOasisContent( KoXmlWriter& writer, KoSavingContext& context ) const;
+
+    // Similar to KoTextDocument::loadOasisText but there's no newline inserted before the first paragraph
+    // or after the last one - so it's possible to paste just a few chars.
+    // It also handles m_lastFormatted
+    KoTextCursor pasteOasisText( const QDomElement &bodyElem, KoOasisContext& context,
+                                 KoTextCursor& cursor, KoStyleCollection * styleColl );
+
 #ifndef NDEBUG
     void printRTDebug(int);
 #endif
 
+    bool statistics( QProgressDialog *progress, ulong & charsWithSpace, ulong & charsWithoutSpace, ulong & words, ulong & sentences, ulong & syllables, ulong & lines, bool selected );
+    int numberOfparagraphLineSelected( KoTextParag *parag);
+
+    /**
+     * Return the variable at the given point (in document coordinates), if any
+     */
+    KoVariable* variableAtPoint( const QPoint& iPoint ) const;
+
+    /**
+     * Return the variable at the given position, if any.
+     * Passing KoTextView's m_cursor here is usually wrong, index must come from the variablePosition
+     * value returned by KoTextCursor::place().
+     */
+    KoVariable* variableAtPosition( KoTextParag* parag, int index ) const;
+
     enum ParagModifyType { AddChar = 0, RemoveChar = 1, ChangeFormat = 2 };
 
 signals:
@@ -473,7 +517,7 @@ public: // made public for KWTextFrameSet...
      * See also the place-holder command (in fact an empty macro-command is created
      * right at the beginning, so that it's possible to undo at any time).
      */
-    struct UndoRedoInfo { // borrowed from QTextEdit
+    struct KOTEXT_EXPORT UndoRedoInfo { // borrowed from QTextEdit
         enum Type { Invalid, Insert, Delete, Return, RemoveSelected };
         UndoRedoInfo( KoTextObject* textobj );
         ~UndoRedoInfo() {}
@@ -529,7 +573,7 @@ private:
 
     /** The style to use by default (initial pararaph, and when deleting a used style)
         TODO: check that we support 0 */
-    KoStyle* m_defaultStyle;
+    KoParagStyle* m_defaultStyle;
 
     bool m_visible;
 
